@@ -1,24 +1,17 @@
 /*
- * "$Id: debug.c 10224 2012-02-03 21:58:58Z mike $"
+ * "$Id: debug.c 12328 2014-12-09 20:38:47Z msweet $"
  *
- *   Debugging functions for CUPS.
+ * Debugging functions for CUPS.
  *
- *   Copyright 2008-2012 by Apple Inc.
+ * Copyright 2008-2014 by Apple Inc.
  *
- *   These coded instructions, statements, and computer programs are the
- *   property of Apple Inc. and are protected by Federal copyright
- *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- *   which should have been included with this file.  If this file is
- *   file is missing or damaged, see the license at "http://www.cups.org/".
+ * These coded instructions, statements, and computer programs are the
+ * property of Apple Inc. and are protected by Federal copyright
+ * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
+ * which should have been included with this file.  If this file is
+ * file is missing or damaged, see the license at "http://www.cups.org/".
  *
- *   This file is subject to the Apple OS-Developed Software exception.
- *
- * Contents:
- *
- *   debug_vsnprintf()    - Format a string into a fixed size buffer.
- *   _cups_debug_printf() - Write a formatted line to the log.
- *   _cups_debug_puts()   - Write a single line to the log.
- *   _cups_debug_set()    - Enable or disable debug logging.
+ * This file is subject to the Apple OS-Developed Software exception.
  */
 
 /*
@@ -68,15 +61,31 @@ int			_cups_debug_level = 1;
 static regex_t		*debug_filter = NULL;
 					/* Filter expression for messages */
 static int		debug_init = 0;	/* Did we initialize debugging? */
-static _cups_mutex_t	debug_mutex = _CUPS_MUTEX_INITIALIZER;
+static _cups_mutex_t	debug_init_mutex = _CUPS_MUTEX_INITIALIZER,
 					/* Mutex to control initialization */
+			debug_log_mutex = _CUPS_MUTEX_INITIALIZER;
+					/* Mutex to serialize log entries */
+
+
+/*
+ * 'debug_thread_id()' - Return an integer representing the current thread.
+ */
+
+static int				/* O - Local thread ID */
+debug_thread_id(void)
+{
+  _cups_globals_t *cg = _cupsGlobals();	/* Global data */
+
+
+  return (cg->thread_id);
+}
 
 
 /*
  * 'debug_vsnprintf()' - Format a string into a fixed size buffer.
  */
 
-static int				/* O - Number of bytes formatted */
+static ssize_t				/* O - Number of bytes formatted */
 debug_vsnprintf(char       *buffer,	/* O - Output buffer */
                 size_t     bufsize,	/* O - Size of output buffer */
 	        const char *format,	/* I - printf-style format string */
@@ -88,11 +97,11 @@ debug_vsnprintf(char       *buffer,	/* O - Output buffer */
 		type;			/* Format type character */
   int		width,			/* Width of field */
 		prec;			/* Number of characters of precision */
-  char		tformat[100],		/* Temporary format string for sprintf() */
+  char		tformat[100],		/* Temporary format string for snprintf() */
 		*tptr,			/* Pointer into temporary format */
 		temp[1024];		/* Buffer for formatted numbers */
   char		*s;			/* Pointer to string */
-  int		bytes;			/* Total number of bytes needed */
+  ssize_t	bytes;			/* Total number of bytes needed */
 
 
   if (!buffer || bufsize < 2 || !format)
@@ -133,7 +142,7 @@ debug_vsnprintf(char       *buffer,	/* O - Output buffer */
 	format ++;
 	width = va_arg(ap, int);
 
-	snprintf(tptr, sizeof(tformat) - (tptr - tformat), "%d", width);
+	snprintf(tptr, sizeof(tformat) - (size_t)(tptr - tformat), "%d", width);
 	tptr += strlen(tptr);
       }
       else
@@ -165,7 +174,7 @@ debug_vsnprintf(char       *buffer,	/* O - Output buffer */
 	  format ++;
 	  prec = va_arg(ap, int);
 
-	  snprintf(tptr, sizeof(tformat) - (tptr - tformat), "%d", prec);
+	  snprintf(tptr, sizeof(tformat) - (size_t)(tptr - tformat), "%d", prec);
 	  tptr += strlen(tptr);
 	}
 	else
@@ -220,25 +229,17 @@ debug_vsnprintf(char       *buffer,	/* O - Output buffer */
 	case 'e' :
 	case 'f' :
 	case 'g' :
-	    if ((width + 2) > sizeof(temp))
+	    if ((size_t)(width + 2) > sizeof(temp))
 	      break;
 
-	    sprintf(temp, tformat, va_arg(ap, double));
+	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, double));
 
             bytes += (int)strlen(temp);
 
             if (bufptr)
 	    {
-	      if ((bufptr + strlen(temp)) > bufend)
-	      {
-		strncpy(bufptr, temp, (size_t)(bufend - bufptr));
-		bufptr = bufend;
-	      }
-	      else
-	      {
-		strcpy(bufptr, temp);
-		bufptr += strlen(temp);
-	      }
+	      strlcpy(bufptr, temp, (size_t)(bufend - bufptr));
+	      bufptr += strlen(bufptr);
 	    }
 	    break;
 
@@ -250,56 +251,40 @@ debug_vsnprintf(char       *buffer,	/* O - Output buffer */
 	case 'o' :
 	case 'u' :
 	case 'x' :
-	    if ((width + 2) > sizeof(temp))
+	    if ((size_t)(width + 2) > sizeof(temp))
 	      break;
 
 #  ifdef HAVE_LONG_LONG
             if (size == 'L')
-	      sprintf(temp, tformat, va_arg(ap, long long));
+	      snprintf(temp, sizeof(temp), tformat, va_arg(ap, long long));
 	    else
 #  endif /* HAVE_LONG_LONG */
             if (size == 'l')
-	      sprintf(temp, tformat, va_arg(ap, long));
+	      snprintf(temp, sizeof(temp), tformat, va_arg(ap, long));
 	    else
-	      sprintf(temp, tformat, va_arg(ap, int));
+	      snprintf(temp, sizeof(temp), tformat, va_arg(ap, int));
 
             bytes += (int)strlen(temp);
 
 	    if (bufptr)
 	    {
-	      if ((bufptr + strlen(temp)) > bufend)
-	      {
-		strncpy(bufptr, temp, (size_t)(bufend - bufptr));
-		bufptr = bufend;
-	      }
-	      else
-	      {
-		strcpy(bufptr, temp);
-		bufptr += strlen(temp);
-	      }
+	      strlcpy(bufptr, temp, (size_t)(bufend - bufptr));
+	      bufptr += strlen(bufptr);
 	    }
 	    break;
 
 	case 'p' : /* Pointer value */
-	    if ((width + 2) > sizeof(temp))
+	    if ((size_t)(width + 2) > sizeof(temp))
 	      break;
 
-	    sprintf(temp, tformat, va_arg(ap, void *));
+	    snprintf(temp, sizeof(temp), tformat, va_arg(ap, void *));
 
             bytes += (int)strlen(temp);
 
 	    if (bufptr)
 	    {
-	      if ((bufptr + strlen(temp)) > bufend)
-	      {
-		strncpy(bufptr, temp, (size_t)(bufend - bufptr));
-		bufptr = bufend;
-	      }
-	      else
-	      {
-		strcpy(bufptr, temp);
-		bufptr += strlen(temp);
-	      }
+	      strlcpy(bufptr, temp, (size_t)(bufend - bufptr));
+	      bufptr += strlen(bufptr);
 	    }
 	    break;
 
@@ -309,7 +294,7 @@ debug_vsnprintf(char       *buffer,	/* O - Output buffer */
 	    if (bufptr)
 	    {
 	      if (width <= 1)
-	        *bufptr++ = va_arg(ap, int);
+	        *bufptr++ = (char)va_arg(ap, int);
 	      else
 	      {
 		if ((bufptr + width) > bufend)
@@ -390,7 +375,7 @@ debug_vsnprintf(char       *buffer,	/* O - Output buffer */
 	    break;
 
 	case 'n' : /* Output number of chars so far */
-	    *(va_arg(ap, int *)) = bytes;
+	    *(va_arg(ap, int *)) = (int)bytes;
 	    break;
       }
     }
@@ -426,7 +411,7 @@ _cups_debug_printf(const char *format,	/* I - Printf-style format string */
   va_list		ap;		/* Pointer to arguments */
   struct timeval	curtime;	/* Current time */
   char			buffer[2048];	/* Output buffer */
-  size_t		bytes;		/* Number of bytes in buffer */
+  ssize_t		bytes;		/* Number of bytes in buffer */
   int			level;		/* Log level in message */
 
 
@@ -457,9 +442,9 @@ _cups_debug_printf(const char *format,	/* I - Printf-style format string */
   {
     int	result;				/* Filter result */
 
-    _cupsMutexLock(&debug_mutex);
+    _cupsMutexLock(&debug_init_mutex);
     result = regexec(debug_filter, format, 0, NULL, 0);
-    _cupsMutexUnlock(&debug_mutex);
+    _cupsMutexUnlock(&debug_init_mutex);
 
     if (result)
       return;
@@ -470,16 +455,16 @@ _cups_debug_printf(const char *format,	/* I - Printf-style format string */
   */
 
   gettimeofday(&curtime, NULL);
-  snprintf(buffer, sizeof(buffer), "%02d:%02d:%02d.%03d ",
-	   (int)((curtime.tv_sec / 3600) % 24),
+  snprintf(buffer, sizeof(buffer), "T%03d %02d:%02d:%02d.%03d  ",
+           debug_thread_id(), (int)((curtime.tv_sec / 3600) % 24),
 	   (int)((curtime.tv_sec / 60) % 60),
 	   (int)(curtime.tv_sec % 60), (int)(curtime.tv_usec / 1000));
 
   va_start(ap, format);
-  bytes = debug_vsnprintf(buffer + 13, sizeof(buffer) - 14, format, ap) + 13;
+  bytes = debug_vsnprintf(buffer + 19, sizeof(buffer) - 20, format, ap) + 19;
   va_end(ap);
 
-  if (bytes >= (sizeof(buffer) - 1))
+  if ((size_t)bytes >= (sizeof(buffer) - 1))
   {
     buffer[sizeof(buffer) - 2] = '\n';
     bytes = sizeof(buffer) - 1;
@@ -494,7 +479,9 @@ _cups_debug_printf(const char *format,	/* I - Printf-style format string */
   * Write it out...
   */
 
-  write(_cups_debug_fd, buffer, bytes);
+  _cupsMutexLock(&debug_log_mutex);
+  write(_cups_debug_fd, buffer, (size_t)bytes);
+  _cupsMutexUnlock(&debug_log_mutex);
 }
 
 
@@ -507,7 +494,7 @@ _cups_debug_puts(const char *s)		/* I - String to output */
 {
   struct timeval	curtime;	/* Current time */
   char			buffer[2048];	/* Output buffer */
-  size_t		bytes;		/* Number of bytes in buffer */
+  ssize_t		bytes;		/* Number of bytes in buffer */
   int			level;		/* Log level in message */
 
 
@@ -538,9 +525,9 @@ _cups_debug_puts(const char *s)		/* I - String to output */
   {
     int	result;				/* Filter result */
 
-    _cupsMutexLock(&debug_mutex);
+    _cupsMutexLock(&debug_init_mutex);
     result = regexec(debug_filter, s, 0, NULL, 0);
-    _cupsMutexUnlock(&debug_mutex);
+    _cupsMutexUnlock(&debug_init_mutex);
 
     if (result)
       return;
@@ -551,13 +538,13 @@ _cups_debug_puts(const char *s)		/* I - String to output */
   */
 
   gettimeofday(&curtime, NULL);
-  bytes = snprintf(buffer, sizeof(buffer), "%02d:%02d:%02d.%03d %s",
-		   (int)((curtime.tv_sec / 3600) % 24),
+  bytes = snprintf(buffer, sizeof(buffer), "T%03d %02d:%02d:%02d.%03d  %s",
+                   debug_thread_id(), (int)((curtime.tv_sec / 3600) % 24),
 		   (int)((curtime.tv_sec / 60) % 60),
 		   (int)(curtime.tv_sec % 60), (int)(curtime.tv_usec / 1000),
 		   s);
 
-  if (bytes >= (sizeof(buffer) - 1))
+  if ((size_t)bytes >= (sizeof(buffer) - 1))
   {
     buffer[sizeof(buffer) - 2] = '\n';
     bytes = sizeof(buffer) - 1;
@@ -572,7 +559,9 @@ _cups_debug_puts(const char *s)		/* I - String to output */
   * Write it out...
   */
 
-  write(_cups_debug_fd, buffer, bytes);
+  _cupsMutexLock(&debug_log_mutex);
+  write(_cups_debug_fd, buffer, (size_t)bytes);
+  _cupsMutexUnlock(&debug_log_mutex);
 }
 
 
@@ -586,7 +575,7 @@ _cups_debug_set(const char *logfile,	/* I - Log file or NULL */
 		const char *filter,	/* I - Filter string or NULL */
 		int        force)	/* I - Force initialization */
 {
-  _cupsMutexLock(&debug_mutex);
+  _cupsMutexLock(&debug_init_mutex);
 
   if (!debug_init || force)
   {
@@ -648,11 +637,11 @@ _cups_debug_set(const char *logfile,	/* I - Log file or NULL */
     debug_init = 1;
   }
 
-  _cupsMutexUnlock(&debug_mutex);
+  _cupsMutexUnlock(&debug_init_mutex);
 }
 #endif /* DEBUG */
 
 
 /*
- * End of "$Id: debug.c 10224 2012-02-03 21:58:58Z mike $".
+ * End of "$Id: debug.c 12328 2014-12-09 20:38:47Z msweet $".
  */
